==> PerItemShipping-1.0.tar.gz: PerItemShipping/function.admin_prefstab.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: PerItemShipping (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module for CMS Made Simple to allow calculating shipping costs
#  based on the number of items in the cart.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Site Preferences') ) exit;

$smarty->assign('formstart',$this->CGCreateFormStart($id,'admin_saveprefs'));
$smarty->assign('formend',$this->CreateFormEnd());
$smarty->assign('itemcost',$this->GetPreference('itemcost','9.95'));
$smarty->assign('count_itemtype',$this->GetPreference('count_itemtype',0));

echo $this->ProcessTemplate('admin_prefstab.tpl');

#
# EOF
#
?>

==> PerItemShipping-1.1.2.tar.gz: PerItemShipping/function.admin_prefstab.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: PerItemShipping (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module for CMS Made Simple to allow calculating shipping costs
#  based on the number of items in the cart.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Site Preferences') ) exit;

$products = cms_utils::get_module('Products');
if( is_object($products) )
  {
    $flddefs = $products->GetFieldDefs();
    if( is_array($flddefs) && count($flddefs) )
      {
	$fields = array();
	$fields[-1] = $this->Lang('none');
	for( $i = 0; $i < count($flddefs); $i++ )
	  {
	    if( $flddefs[$i]->type == 'textbox' || $flddefs[$i]->type == 'dropdown' )
	      {
		$fields[$flddefs[$i]->id] = $flddefs[$i]->prompt;
	      }
	  }
	$smarty->assign('fielddefs',$fields);
	$smarty->assign('shipping_field',$this->GetPreference('shipping_field',-1));
      }
  }
$smarty->assign('formstart',$this->CGCreateFormStart($id,'admin_saveprefs'));
$smarty->assign('formend',$this->CreateFormEnd());
$smarty->assign('itemcost',$this->GetPreference('itemcost','9.95'));
$smarty->assign('count_itemtype',$this->GetPreference('count_itemtype',0));

echo $this->ProcessTemplate('admin_prefstab.tpl');

#
# EOF
#
?>
